@@ -169,15 +169,20 @@ function config_trove_apache_wsgi {
     local trove_apache_conf
 
     sudo mkdir -p ${TROVE_WSGI_DIR}
-    sudo cp $TROVE_DIR/trove/cmd/app.wsgi $TROVE_WSGI_DIR/app.wsgi
+    sudo cp $TROVE_DIR/trove/cmd/app_wsgi.py $TROVE_WSGI_DIR/app_wsgi.py
     trove_apache_conf=$(apache_site_config_for trove-api)
     sudo cp $TROVE_DEVSTACK_FILES/apache-trove-api.template ${trove_apache_conf}
+    local wsgi_venv_config=""
+    if [[ "$GLOBAL_VENV" == "True" ]] ; then
+        wsgi_venv_config="WSGIPythonHome $DEVSTACK_VENV"
+    fi
     sudo sed -e "
         s|%TROVE_SERVICE_PORT%|${TROVE_SERVICE_PORT}|g;
         s|%TROVE_WSGI_DIR%|${TROVE_WSGI_DIR}|g;
         s|%USER%|${STACK_USER}|g;
         s|%APACHE_NAME%|${APACHE_NAME}|g;
         s|%APIWORKERS%|${API_WORKERS}|g;
+        s|%WSGIPYTHONHOME%|${wsgi_venv_config}|g;
     " -i ${trove_apache_conf}
     enable_apache_site trove-api
 }
@@ -229,7 +234,6 @@ function configure_trove {
 
     iniset $TROVE_CONF database connection `database_connection_url trove`
 
-    iniset $TROVE_CONF DEFAULT rpc_backend "rabbit"
     iniset $TROVE_CONF DEFAULT control_exchange trove
     iniset $TROVE_CONF DEFAULT transport_url rabbit://$RABBIT_USERID:$RABBIT_PASSWORD@$RABBIT_HOST:5672/
     iniset $TROVE_CONF DEFAULT trove_api_workers "$API_WORKERS"
@@ -257,7 +261,6 @@ function configure_trove {
 
     iniset_conditional $TROVE_GUESTAGENT_CONF DEFAULT state_change_wait_time $TROVE_STATE_CHANGE_WAIT_TIME
     iniset_conditional $TROVE_GUESTAGENT_CONF DEFAULT command_process_timeout $TROVE_COMMAND_PROCESS_TIMEOUT
-    iniset $TROVE_GUESTAGENT_CONF DEFAULT rpc_backend "rabbit"
     iniset $TROVE_GUESTAGENT_CONF DEFAULT transport_url rabbit://$RABBIT_USERID:$RABBIT_PASSWORD@$TROVE_HOST_GATEWAY:5672/
     iniset $TROVE_GUESTAGENT_CONF DEFAULT control_exchange trove
     iniset $TROVE_GUESTAGENT_CONF DEFAULT ignore_users os_admin
@@ -274,6 +277,8 @@ function configure_trove {
 
     iniset $TROVE_GUESTAGENT_CONF mysql docker_image ${TROVE_DATABASE_IMAGE_MYSQL}
     iniset $TROVE_GUESTAGENT_CONF mysql backup_docker_image ${TROVE_DATABASE_BACKUP_IMAGE_MYSQL}
+    iniset $TROVE_GUESTAGENT_CONF mariadb docker_image ${TROVE_DATABASE_IMAGE_MARIADB}
+    iniset $TROVE_GUESTAGENT_CONF mariadb backup_docker_image ${TROVE_DATABASE_BACKUP_IMAGE_MARIADB}
     iniset $TROVE_GUESTAGENT_CONF postgresql docker_image ${TROVE_DATABASE_IMAGE_POSTGRES}
     iniset $TROVE_GUESTAGENT_CONF postgresql backup_docker_image ${TROVE_DATABASE_BACKUP_IMAGE_POSTGRES}
 
@@ -348,8 +353,9 @@ function create_mgmt_subnet_v4 {
     local net_id=$2
     local name=$3
     local ip_range=$4
+    local gateway=$5
 
-    subnet_id=$(openstack subnet create --project ${project_id} --ip-version 4 --subnet-range ${ip_range} --gateway none --dns-nameserver 8.8.8.8 --network ${net_id} $name -c id -f value)
+    subnet_id=$(openstack subnet create --project ${project_id} --ip-version 4 --subnet-range ${ip_range} --gateway ${gateway} --dns-nameserver 8.8.8.8 --network ${net_id} $name -c id -f value)
     die_if_not_set $LINENO subnet_id "Failed to create private IPv4 subnet for network: ${net_id}, project: ${project_id}"
     echo $subnet_id
 }
@@ -386,7 +392,8 @@ function setup_mgmt_network() {
     local NET_NAME=$2
     local SUBNET_NAME=$3
     local SUBNET_RANGE=$4
-    local SHARED=$5
+    local SUBNET_GATEWAY=$5
+    local SHARED=$6
 
     local share_flag=""
     if [[ "${SHARED}" == "TRUE" ]]; then
@@ -397,9 +404,10 @@ function setup_mgmt_network() {
     die_if_not_set $LINENO network_id "Failed to create network: $NET_NAME, project: ${PROJECT_ID}"
 
     if [[ "$IP_VERSION" =~ 4.* ]]; then
-        net_subnet_id=$(create_mgmt_subnet_v4 ${PROJECT_ID} ${network_id} ${SUBNET_NAME} ${SUBNET_RANGE})
-        # 'openstack router add' has a bug that cound't show the error message
-        # openstack router add subnet ${ROUTER_ID} ${net_subnet_id} --debug
+        net_subnet_id=$(create_mgmt_subnet_v4 ${PROJECT_ID} ${network_id} ${SUBNET_NAME} ${SUBNET_RANGE} ${SUBNET_GATEWAY})
+        if [[ ${SUBNET_GATEWAY} != "none" ]]; then
+            openstack router add subnet ${ROUTER_ID} ${net_subnet_id}
+        fi
     fi
 
     # Trove doesn't support IPv6 for now.
@@ -463,7 +471,7 @@ function create_guest_image {
         curl -sSL ${TROVE_NON_DEV_IMAGE_URL} -o ${image_file}
     else
         echo "Starting to create guest image"
-
+        export SYNC_LOG_TO_CONTROLLER=${SYNC_LOG_TO_CONTROLLER:-"False"}
         $DEST/trove/integration/scripts/trovestack \
           build-image \
           ${TROVE_IMAGE_OS} \
@@ -499,6 +507,45 @@ function create_guest_image {
         $TROVE_MANAGE db_load_datastore_config_parameters "$TROVE_DATASTORE_TYPE" "$TROVE_DATASTORE_VERSION" \
             $DEST/trove/trove/templates/$TROVE_DATASTORE_TYPE/validation-rules.json
     fi
+    # NOTE(wuchunyang): Create log directory so that guest agent can rsync logs to this directory
+    if [[ ${SYNC_LOG_TO_CONTROLLER} == "True" ]]; then
+    test -e /var/log/guest-agent-logs || sudo mkdir -p /var/log/guest-agent-logs/ && sudo chmod 777 /var/log/guest-agent-logs
+    fi
+}
+
+function create_registry_container {
+    # install docker on the host.
+    local ret='0'
+    which docker >/dev/null 2>&1 || { local ret='1'; }
+    if [[ "$ret" -ne 0 ]]; then
+        echo "Installing docker on the host"
+        $DEST/trove/integration/scripts/trovestack install-docker
+    fi
+    # running a docker registry container
+    echo "Running a docker registry container..."
+    container=$(sudo docker ps -a --format "{{.Names}}" --filter name=registry)
+    if [ -z $container ]; then
+        sudo docker run -d --net=host -e REGISTRY_HTTP_ADDR=0.0.0.0:4000 --restart=always -v /opt/trove_registry/:/var/lib/registry --name registry registry:2
+        for img in {"mysql:5.7.29","mysql:8.0","mariadb:10.4","postgres:12"};
+        do
+        sudo docker pull ${img} && sudo docker tag ${img} 127.0.0.1:4000/trove-datastores/${img} && sudo docker push 127.0.0.1:4000/trove-datastores/${img}
+        done
+        pushd $DEST/trove/backup
+        # build backup images
+        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-mysql5.7:1.1.0 --build-arg DATASTORE=mysql5.7 .
+        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-mysql8.0:1.1.0 --build-arg DATASTORE=mysql8.0 .
+        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-mariadb:1.1.0 --build-arg DATASTORE=mariadb .
+        sudo docker build --network host -t 127.0.0.1:4000/trove-datastores/db-backup-postgresql:1.1.2 --build-arg DATASTORE=postgresql .
+        popd
+        # push backup images
+        for backupimg in {"db-backup-mysql5.7:1.1.0","db-backup-mysql8.0:1.1.0","db-backup-mariadb:1.1.0","db-backup-postgresql:1.1.2"};
+        do
+        sudo docker push 127.0.0.1:4000/trove-datastores/${backupimg}
+        done
+        # clean up backup images.
+        sudo docker image prune -a -f
+    fi
+    iniset $TROVE_CONF DEFAULT docker_insecure_registries "$TROVE_HOST_GATEWAY:4000"
 }
 
 # Set up Trove management network and make configuration change.
@@ -518,6 +565,7 @@ function config_trove_network {
     echo "  SUBNETPOOL_V4_ID: $SUBNETPOOL_V4_ID"
     echo "  ROUTER_GW_IP: $ROUTER_GW_IP"
     echo "  TROVE_MGMT_SUBNET_RANGE: ${TROVE_MGMT_SUBNET_RANGE}"
+    echo "  TROVE_MGMT_GATEWAY: ${TROVE_MGMT_GATEWAY}"
 
     # Save xtrace setting
     local orig_xtrace
@@ -526,7 +574,7 @@ function config_trove_network {
 
     echo "Creating Trove management network/subnet for Trove service project."
     trove_service_project_id=$(openstack project show $SERVICE_PROJECT_NAME -c id -f value)
-    setup_mgmt_network ${trove_service_project_id} ${TROVE_MGMT_NETWORK_NAME} ${TROVE_MGMT_SUBNET_NAME} ${TROVE_MGMT_SUBNET_RANGE}
+    setup_mgmt_network ${trove_service_project_id} ${TROVE_MGMT_NETWORK_NAME} ${TROVE_MGMT_SUBNET_NAME} ${TROVE_MGMT_SUBNET_RANGE} ${TROVE_MGMT_GATEWAY}
     mgmt_net_id=$(openstack network show ${TROVE_MGMT_NETWORK_NAME} -c id -f value)
     echo "Created Trove management network ${TROVE_MGMT_NETWORK_NAME}(${mgmt_net_id})"
 
@@ -538,7 +586,9 @@ function config_trove_network {
     if [[ "$shared" == "False" ]]; then
         openstack network set ${PRIVATE_NETWORK_NAME} --share
     fi
-    sudo ip route replace ${IPV4_ADDRS_SAFE_TO_USE} via $ROUTER_GW_IP
+    if [[ -n ${ROUTER_GW_IP} && -n ${IPV4_ADDRS_SAFE_TO_USE} ]]; then
+        sudo ip route replace ${IPV4_ADDRS_SAFE_TO_USE} via $ROUTER_GW_IP
+    fi
 
     # Make sure we can reach the management port of the service VM, this
     # configuration is only for testing purpose. In production, it's
@@ -637,6 +687,9 @@ if is_service_enabled trove; then
         config_mgmt_security_group
         config_trove_network
         create_guest_image
+        if [ "$TROVE_ENABLE_LOCAL_REGISTRY" == "True" ] ; then
+            create_registry_container
+        fi
 
         echo_summary "Starting Trove"
         start_trove
