@@ -46,7 +46,7 @@ class Commands(object):
 
     def execute(self):
         exec_method = getattr(self, CONF.action.name)
-        args = inspect.getargspec(exec_method)
+        args = inspect.getfullargspec(exec_method)
         args.args.remove('self')
         kwargs = {}
         for arg in args.args:
@@ -62,14 +62,18 @@ class Commands(object):
             print(e)
 
     def datastore_version_update(self, datastore, version_name, manager,
-                                 image_id, packages, active):
+                                 image_id, packages, active, image_tags=None,
+                                 version=None):
         try:
             datastore_models.update_datastore_version(datastore,
                                                       version_name,
                                                       manager,
                                                       image_id,
-                                                      packages, active)
-            print("Datastore version '%s' updated." % version_name)
+                                                      image_tags,
+                                                      packages, active,
+                                                      version=version)
+            print("Datastore version '%s(%s)' updated." %
+                  (version_name, version or version_name))
         except exception.DatastoreNotFound as e:
             print(e)
 
@@ -81,77 +85,113 @@ class Commands(object):
     def db_load_datastore_config_parameters(self,
                                             datastore,
                                             datastore_version_name,
-                                            config_file_location):
+                                            config_file_location,
+                                            version=None):
         print("Loading config parameters for datastore (%s) version (%s)"
               % (datastore, datastore_version_name))
         config_models.load_datastore_configuration_parameters(
-            datastore, datastore_version_name, config_file_location)
+            datastore, datastore_version_name, config_file_location,
+            version_number=version)
 
     def db_remove_datastore_config_parameters(self, datastore,
-                                              datastore_version_name):
+                                              datastore_version_name,
+                                              version=None):
         print("Removing config parameters for datastore (%s) version (%s)"
               % (datastore, datastore_version_name))
         config_models.remove_datastore_configuration_parameters(
-            datastore, datastore_version_name)
+            datastore, datastore_version_name, version_number=version)
 
     def datastore_version_flavor_add(self, datastore_name,
-                                     datastore_version_name, flavor_ids):
+                                     datastore_version_name, flavor_ids,
+                                     version=None):
         """Adds flavors for a given datastore version id."""
+        dsmetadata = datastore_models.DatastoreVersionMetadata
         try:
-            dsmetadata = datastore_models.DatastoreVersionMetadata
+            datastore_version_id = dsmetadata.datastore_version_find(
+                datastore_name,
+                datastore_version_name,
+                version_number=version)
+
             dsmetadata.add_datastore_version_flavor_association(
-                datastore_name, datastore_version_name, flavor_ids.split(","))
+                datastore_version_id, flavor_ids.split(","))
             print("Added flavors '%s' to the '%s' '%s'."
                   % (flavor_ids, datastore_name, datastore_version_name))
-        except exception.DatastoreVersionNotFound as e:
+        except Exception as e:
             print(e)
 
     def datastore_version_flavor_delete(self, datastore_name,
-                                        datastore_version_name, flavor_id):
+                                        datastore_version_name, flavor_id,
+                                        version=None):
         """Deletes a flavor's association with a given datastore."""
         try:
             dsmetadata = datastore_models.DatastoreVersionMetadata
+
+            datastore_version_id = dsmetadata.datastore_version_find(
+                datastore_name,
+                datastore_version_name,
+                version_number=version)
+
             dsmetadata.delete_datastore_version_flavor_association(
-                datastore_name, datastore_version_name, flavor_id)
+                datastore_version_id, flavor_id)
             print("Deleted flavor '%s' from '%s' '%s'."
                   % (flavor_id, datastore_name, datastore_version_name))
-        except exception.DatastoreVersionNotFound as e:
+        except Exception as e:
             print(e)
 
     def datastore_version_volume_type_add(self, datastore_name,
                                           datastore_version_name,
-                                          volume_type_ids):
+                                          volume_type_ids, version=None):
         """Adds volume type assiciation for a given datastore version id."""
         try:
             dsmetadata = datastore_models.DatastoreVersionMetadata
+
+            datastore_version_id = dsmetadata.datastore_version_find(
+                datastore_name,
+                datastore_version_name,
+                version_number=version)
+
             dsmetadata.add_datastore_version_volume_type_association(
-                datastore_name, datastore_version_name,
+                datastore_version_id,
                 volume_type_ids.split(","))
             print("Added volume type '%s' to the '%s' '%s'."
                   % (volume_type_ids, datastore_name, datastore_version_name))
-        except exception.DatastoreVersionNotFound as e:
+        except Exception as e:
             print(e)
 
     def datastore_version_volume_type_delete(self, datastore_name,
                                              datastore_version_name,
-                                             volume_type_id):
+                                             volume_type_id, version=None):
         """Deletes a volume type association with a given datastore."""
         try:
             dsmetadata = datastore_models.DatastoreVersionMetadata
+
+            datastore_version_id = dsmetadata.datastore_version_find(
+                datastore_name,
+                datastore_version_name,
+                version_number=version)
+
             dsmetadata.delete_datastore_version_volume_type_association(
-                datastore_name, datastore_version_name, volume_type_id)
+                datastore_version_id, volume_type_id)
             print("Deleted volume type '%s' from '%s' '%s'."
                   % (volume_type_id, datastore_name, datastore_version_name))
-        except exception.DatastoreVersionNotFound as e:
+        except Exception as e:
             print(e)
 
     def datastore_version_volume_type_list(self, datastore_name,
-                                           datastore_version_name):
+                                           datastore_version_name,
+                                           version=None):
         """Lists volume type association with a given datastore."""
         try:
             dsmetadata = datastore_models.DatastoreVersionMetadata
-            vtlist = dsmetadata.list_datastore_volume_type_associations(
-                datastore_name, datastore_version_name)
+
+            datastore_version_id = dsmetadata.datastore_version_find(
+                datastore_name,
+                datastore_version_name,
+                version_number=version)
+
+            vtlist = dsmetadata. \
+                list_datastore_version_volume_type_associations(
+                    datastore_version_id)
             if vtlist.count() > 0:
                 for volume_type in vtlist:
                     print("Datastore: %s, Version: %s, Volume Type: %s" %
@@ -161,7 +201,7 @@ class Commands(object):
                 print("No Volume Type Associations found for Datastore: %s, "
                       "Version: %s." %
                       (datastore_name, datastore_version_name))
-        except exception.DatastoreVersionNotFound as e:
+        except Exception as e:
             print(e)
 
     def params_of(self, command_name):
@@ -208,8 +248,9 @@ def main():
             'manager', help='Name of the manager that will administer the '
             'datastore version.')
         parser.add_argument(
-            'image_id', help='ID of the image used to create an instance of '
-            'the datastore version.')
+            'image_id',
+            help='ID of the image used to create an instance of '
+                 'the datastore version.')
         parser.add_argument(
             'packages', help='Packages required by the datastore version that '
             'are installed on the guest image.')
@@ -217,6 +258,14 @@ def main():
             'active', type=int,
             help='Whether the datastore version is active or not. '
             'Accepted values are 0 and 1.')
+        parser.add_argument(
+            '--image-tags',
+            help='List of image tags separated by comma used for getting '
+                 'guest image.')
+        parser.add_argument(
+            '--version',
+            help='The version number of the datastore version, e.g. 5.7.30. '
+                 'If not specified, use <version_name> as default value.')
 
         parser = subparser.add_parser(
             'db_recreate', description='Drop the database and recreate it.')
@@ -236,6 +285,11 @@ def main():
             'config_file_location',
             help='Fully qualified file path to the configuration group '
             'parameter validation rules.')
+        parser.add_argument(
+            '--version',
+            help='The version number of the datastore version, e.g. 5.7.30. '
+                 'If not specified, use <datastore_version_name> as default '
+                 'value.')
 
         parser = subparser.add_parser(
             'db_remove_datastore_config_parameters',
@@ -247,51 +301,86 @@ def main():
         parser.add_argument(
             'datastore_version_name',
             help='Name of the datastore version.')
+        parser.add_argument(
+            '--version',
+            help='The version number of the datastore version, e.g. 5.7.30. '
+                 'If not specified, use <datastore_version_name> as default '
+                 'value.')
 
         parser = subparser.add_parser(
-            'datastore_version_flavor_add', help='Adds flavor association to '
-            'a given datastore and datastore version.')
+            'datastore_version_flavor_add',
+            help='Adds flavor association to a given datastore and datastore '
+                 'version.')
         parser.add_argument('datastore_name', help='Name of the datastore.')
         parser.add_argument('datastore_version_name', help='Name of the '
                             'datastore version.')
         parser.add_argument('flavor_ids', help='Comma separated list of '
                             'flavor ids.')
+        parser.add_argument(
+            '--version',
+            help='The version number of the datastore version, e.g. 5.7.30. '
+                 'If not specified, use <datastore_version_name> as default '
+                 'value.')
 
         parser = subparser.add_parser(
-            'datastore_version_flavor_delete', help='Deletes a flavor '
-            'associated with a given datastore and datastore version.')
+            'datastore_version_flavor_delete',
+            help='Deletes a flavor associated with a given datastore and '
+                 'datastore version.')
         parser.add_argument('datastore_name', help='Name of the datastore.')
         parser.add_argument('datastore_version_name', help='Name of the '
                             'datastore version.')
         parser.add_argument('flavor_id', help='The flavor to be deleted for '
                             'a given datastore and datastore version.')
+        parser.add_argument(
+            '--version',
+            help='The version number of the datastore version, e.g. 5.7.30. '
+                 'If not specified, use <datastore_version_name> as default '
+                 'value.')
+
         parser = subparser.add_parser(
-            'datastore_version_volume_type_add', help='Adds volume_type '
-            'association to a given datastore and datastore version.')
+            'datastore_version_volume_type_add',
+            help='Adds volume_type association to a given datastore and '
+                 'datastore version.')
         parser.add_argument('datastore_name', help='Name of the datastore.')
         parser.add_argument('datastore_version_name', help='Name of the '
                             'datastore version.')
         parser.add_argument('volume_type_ids', help='Comma separated list of '
                             'volume_type ids.')
+        parser.add_argument(
+            '--version',
+            help='The version number of the datastore version, e.g. 5.7.30. '
+                 'If not specified, use <datastore_version_name> as default '
+                 'value.')
 
         parser = subparser.add_parser(
             'datastore_version_volume_type_delete',
             help='Deletes a volume_type '
-            'associated with a given datastore and datastore version.')
+                 'associated with a given datastore and datastore version.')
         parser.add_argument('datastore_name', help='Name of the datastore.')
         parser.add_argument('datastore_version_name', help='Name of the '
                             'datastore version.')
         parser.add_argument('volume_type_id', help='The volume_type to be '
                             'deleted for a given datastore and datastore '
                             'version.')
+        parser.add_argument(
+            '--version',
+            help='The version number of the datastore version, e.g. 5.7.30. '
+                 'If not specified, use <datastore_version_name> as default '
+                 'value.')
 
         parser = subparser.add_parser(
             'datastore_version_volume_type_list',
             help='Lists the volume_types '
-            'associated with a given datastore and datastore version.')
+                 'associated with a given datastore and datastore version.')
         parser.add_argument('datastore_name', help='Name of the datastore.')
         parser.add_argument('datastore_version_name', help='Name of the '
                             'datastore version.')
+        parser.add_argument(
+            '--version',
+            help='The version number of the datastore version, e.g. 5.7.30. '
+                 'If not specified, use <datastore_version_name> as default '
+                 'value.')
+
     cfg.custom_parser('action', actions)
     cfg.parse_args(sys.argv)
 
