@@ -20,8 +20,8 @@ import os.path
 from keystoneauth1 import loading
 from keystonemiddleware import auth_token
 from oslo_config import cfg
-from oslo_config import types
 from oslo_config.cfg import NoSuchOptError
+from oslo_config import types
 from oslo_log import log as logging
 from oslo_log import versionutils
 from oslo_middleware import cors
@@ -201,6 +201,8 @@ common_opts = [
                     'change.'),
     cfg.IntOpt('state_change_poll_time', default=3,
                help='Interval between state change poll requests (seconds).'),
+    cfg.IntOpt('state_healthy_counts', default=5,
+               help='consecutive success db connections for status HEALTHY'),
     cfg.IntOpt('agent_heartbeat_time', default=10,
                help='Maximum time (in seconds) for the Guest Agent to reply '
                     'to a heartbeat request.'),
@@ -538,10 +540,8 @@ database_opts = [
                secret=True,
                deprecated_name='sql_connection',
                deprecated_group='DEFAULT'),
-    cfg.IntOpt('idle_timeout',
-               default=3600,
-               deprecated_name='sql_idle_timeout',
-               deprecated_group='DEFAULT'),
+    cfg.IntOpt('connection_recycle_time',
+               default=3600),
     cfg.BoolOpt('query_log',
                 default=False,
                 deprecated_name='sql_query_log',
@@ -1480,7 +1480,14 @@ network_opts = [
              'This is needed for the instance initialization. The check is '
              'also necessary when creating public facing instance. A scenario '
              'to set this option False is when using Neutron provider '
-             'network.')
+             'network.'
+    ),
+    cfg.BoolOpt(
+        'network_isolation', default=False,
+        help='whether to plug user defined port to database container.'
+             'This would be useful to isolate user traffic from management'
+             'traffic and to avoid network address conflicts.'
+    )
 ]
 
 service_credentials_group = cfg.OptGroup(
