@@ -21,8 +21,7 @@ from trove.cluster.views import ClusterView
 from trove.common import cfg
 from trove.common import server_group as srv_grp
 from trove.common.strategies.cluster import base
-from trove.common.strategies.cluster.experimental.cassandra.taskmanager import(
-    CassandraClusterTasks)
+from trove.common.strategies.cluster.experimental.cassandra import taskmanager
 from trove.common import utils
 from trove.extensions.mgmt.clusters.views import MgmtClusterView
 from trove.instance import models as inst_models
@@ -82,12 +81,13 @@ class CassandraCluster(models.Cluster):
 
     @classmethod
     def create(cls, context, name, datastore, datastore_version,
-               instances, extended_properties, locality, configuration):
+               instances, extended_properties, locality, configuration,
+               image_id=None):
         LOG.debug("Processing a request for creating a new cluster.")
 
         # Updating Cluster Task.
         db_info = models.DBCluster.create(
-            name=name, tenant_id=context.tenant,
+            name=name, tenant_id=context.project_id,
             datastore_version_id=datastore_version.id,
             task_status=ClusterTasks.BUILDING_INITIAL,
             configuration_id=configuration)
@@ -126,14 +126,15 @@ class CassandraCluster(models.Cluster):
         num_new_instances = len(instances)
         deltas = {'instances': num_new_instances, 'volumes': req_volume_size}
         models.assert_homogeneous_cluster(instances)
-        check_quotas(context.tenant, deltas)
+        check_quotas(context.project_id, deltas)
 
         # Checking networks are same for the cluster
         models.validate_instance_nics(context, instances)
 
         # Creating member instances.
         num_instances = len(
-            CassandraClusterTasks.find_cluster_node_ids(cluster_id))
+            taskmanager.CassandraClusterTasks.find_cluster_node_ids(cluster_id)
+        )
         new_instances = []
         for instance_idx, instance in enumerate(instances, num_instances + 1):
             instance_az = instance.get('availability_zone', None)
