@@ -17,9 +17,10 @@
 from collections import abc
 import inspect
 import os
+import shlex
 import shutil
-import uuid
 import urllib.parse as urlparse
+import uuid
 
 from eventlet.timeout import Timeout
 import jinja2
@@ -174,7 +175,7 @@ class MethodInspector(object):
 
     @cached_property
     def argspec(self):
-        return inspect.getargspec(self._func)
+        return inspect.getfullargspec(self._func)
 
     def __str__(self):
         optionals = ["[{0}=<{0}>]".format(k) for k, v in self.optional_args]
@@ -423,3 +424,13 @@ def req_to_text(req):
         parts.extend([b'', safe_encode(req.body)])
 
     return b'\r\n'.join(parts).decode(req.charset)
+
+
+def validate_command(string):
+    """
+    Check if the string is legal for command
+
+    raise invalidvalue if illegal
+    """
+    if string != shlex.quote(string):
+        raise exception.InvalidValue(value=string)
