@@ -26,15 +26,15 @@ from trove.common import cfg
 from trove.common import exception
 from trove.common.i18n import _
 from trove.common.notification import EndNotification
-from trove.guestagent import dbaas
-from trove.guestagent import guest_log
-from trove.guestagent import volume
 from trove.guestagent.common import guestagent_utils
 from trove.guestagent.common import operating_system
 from trove.guestagent.common.operating_system import FileMode
+from trove.guestagent import dbaas
+from trove.guestagent import guest_log
 from trove.guestagent.module import driver_manager
 from trove.guestagent.module import module_manager
 from trove.guestagent.strategies import replication as repl_strategy
+from trove.guestagent import volume
 from trove.instance import service_status
 
 LOG = logging.getLogger(__name__)
@@ -511,7 +511,7 @@ class Manager(periodic_task.PeriodicTasks):
                         exposed)
 
                     if (gl_def[self.GUEST_LOG_TYPE_LABEL] ==
-                        guest_log.LogType.USER):
+                            guest_log.LogType.USER):
                         guestlog.enabled = self.is_log_enabled(log_name)
                         guestlog.status = (guest_log.LogStatus.Enabled
                                            if guestlog.enabled
@@ -882,7 +882,7 @@ class Manager(periodic_task.PeriodicTasks):
         self.replication.enable_as_master(self.app, replica_source_config)
         LOG.info('Enabled as replication master')
 
-        snapshot_id, log_position = self.replication.snapshot_for_replication(
+        snapshot_id, replica_conf = self.replication.snapshot_for_replication(
             context, self.app, self.adm, None, snapshot_info)
 
         volume_stats = self.get_filesystem_stats(context, None)
@@ -896,7 +896,7 @@ class Manager(periodic_task.PeriodicTasks):
             },
             'replication_strategy': self.replication_strategy,
             'master': self.replication.get_master_ref(self.app, snapshot_info),
-            'log_position': log_position
+            'replica_conf': replica_conf
         }
 
         return replication_snapshot
