@@ -13,26 +13,29 @@
 #    limitations under the License.
 
 import abc
+import os
 import re
 
 from oslo_log import log as logging
 from oslo_utils import encodeutils
 import sqlalchemy
+from sqlalchemy import event
 from sqlalchemy import exc
 from sqlalchemy.sql.expression import text
 import urllib
 
 from trove.common import cfg
-from trove.common import exception
-from trove.common import utils
 from trove.common.configurations import MySQLConfParser
+from trove.common import constants
 from trove.common.db.mysql import models
+from trove.common import exception
 from trove.common.i18n import _
+from trove.common import utils
+from trove.guestagent.common.configuration import ConfigurationManager
+from trove.guestagent.common.configuration import ImportOverrideStrategy
 from trove.guestagent.common import guestagent_utils
 from trove.guestagent.common import operating_system
 from trove.guestagent.common import sql_query
-from trove.guestagent.common.configuration import ConfigurationManager
-from trove.guestagent.common.configuration import ImportOverrideStrategy
 from trove.guestagent.datastore import service
 from trove.guestagent.utils import docker as docker_util
 from trove.guestagent.utils import mysql as mysql_util
@@ -59,6 +62,7 @@ BACKUP_LOG = re.compile(r'.*Backup successfully, checksum: (?P<checksum>.*), '
 
 
 class BaseMySqlAppStatus(service.BaseDbStatus):
+
     def __init__(self, docker_client):
         super(BaseMySqlAppStatus, self).__init__(docker_client)
 
@@ -103,7 +107,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         """Internal. Given a MySQLUser, populate its databases attribute."""
         LOG.debug("Associating dbs to user %(name)s at %(host)s.",
                   {'name': user.name, 'host': user.host})
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             q = sql_query.Query()
             q.columns = ["grantee", "table_schema"]
             q.tables = ["information_schema.SCHEMA_PRIVILEGES"]
@@ -119,7 +124,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
     def change_passwords(self, users):
         """Change the passwords of one or more existing users."""
         LOG.debug("Changing the password of some users.")
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             for item in users:
                 LOG.debug("Changing password for user %s.", item)
                 user_dict = {'_name': item['name'],
@@ -143,7 +149,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         new_password = user_attrs.get('password')
 
         if new_name or new_host or new_password:
-            with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+            with mysql_util.SqlClient(
+                    self.mysql_app.get_engine(), use_flush=True) as client:
                 if new_password is not None:
                     uu = sql_query.SetPassword(
                         user.name, host=user.host,
@@ -162,7 +169,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
 
     def create_databases(self, databases):
         """Create the list of specified databases."""
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             for item in databases:
                 mydb = models.MySQLSchema.deserialize(item)
                 mydb.check_create()
@@ -177,7 +185,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         """Create users and grant them privileges for the
            specified databases.
         """
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             for item in users:
                 user = models.MySQLUser.deserialize(item)
                 user.check_create()
@@ -197,7 +206,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
 
     def delete_database(self, database):
         """Delete the specified database."""
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             mydb = models.MySQLSchema.deserialize(database)
             mydb.check_delete()
             dd = sql_query.DropDatabase(mydb.name)
@@ -211,7 +221,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         self.delete_user_by_name(mysql_user.name, mysql_user.host)
 
     def delete_user_by_name(self, name, host='%'):
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             du = sql_query.DropUser(name, host=host)
             t = text(str(du))
             LOG.debug("delete_user_by_name: %s", t)
@@ -237,7 +248,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
                                          ": %(reason)s") %
                                        {'user': username, 'reason': err_msg}
                                        )
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             q = sql_query.Query()
             q.columns = ['User', 'Host']
             q.tables = ['mysql.user']
@@ -259,7 +271,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         """Grant a user permission to use a given database."""
         user = self._get_user(username, hostname)
         mydb = None  # cache the model as we just want name validation
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             for database in databases:
                 try:
                     if mydb:
@@ -362,7 +375,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
         LOG.debug("The following user names are on ignore list and will "
                   "be omitted from the listing: %s", ignored_user_names)
         users = []
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             iq = sql_query.Query()  # Inner query.
             iq.columns = ['User', 'Host', "CONCAT(User, '@', Host) as Marker"]
             iq.tables = ['mysql.user']
@@ -404,7 +418,8 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
     def revoke_access(self, username, hostname, database):
         """Revoke a user's permission to use a given database."""
         user = self._get_user(username, hostname)
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             r = sql_query.Revoke(database=database,
                                  user=user.name,
                                  host=user.host)
@@ -420,11 +435,19 @@ class BaseMySqlAdmin(object, metaclass=abc.ABCMeta):
 
 
 class BaseMySqlApp(service.BaseDbApp):
-    configuration_manager = ConfigurationManager(
-        MYSQL_CONFIG, CONF.database_service_uid, CONF.database_service_uid,
-        service.BaseDbApp.CFG_CODEC, requires_root=True,
-        override_strategy=ImportOverrideStrategy(CNF_INCLUDE_DIR, CNF_EXT)
-    )
+    _configuration_manager = None
+
+    @property
+    def configuration_manager(self):
+        if self._configuration_manager:
+            return self._configuration_manager
+
+        self._configuration_manager = ConfigurationManager(
+            MYSQL_CONFIG, CONF.database_service_uid, CONF.database_service_uid,
+            service.BaseDbApp.CFG_CODEC, requires_root=True,
+            override_strategy=ImportOverrideStrategy(CNF_INCLUDE_DIR, CNF_EXT)
+        )
+        return self._configuration_manager
 
     def get_engine(self):
         """Create the default engine with the updated admin user.
@@ -435,35 +458,35 @@ class BaseMySqlApp(service.BaseDbApp):
         if ENGINE:
             return ENGINE
 
-        user = ADMIN_USER_NAME
-        password = ""
         try:
+            user = ADMIN_USER_NAME
             password = self.get_auth_password()
         except exception.UnprocessableEntity:
             # os_admin user not created yet
             user = 'root'
+            password = self.get_auth_password(file="root.cnf")
 
         ENGINE = sqlalchemy.create_engine(
             CONNECTION_STR_FORMAT % (user,
                                      urllib.parse.quote(password.strip())),
-            pool_recycle=120, echo=CONF.sql_query_logging,
-            listeners=[mysql_util.BaseKeepAliveConnection()])
+            pool_recycle=120, echo=CONF.sql_query_logging
+        )
+        event.listen(ENGINE, 'checkout', mysql_util.connection_checkout)
 
         return ENGINE
 
-    def execute_sql(self, sql_statement):
+    def execute_sql(self, sql_statement, use_flush=False):
         LOG.debug("Executing SQL: %s", sql_statement)
-        with mysql_util.SqlClient(self.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.get_engine(), use_flush=use_flush) as client:
             return client.execute(sql_statement)
 
-    @classmethod
-    def get_data_dir(cls):
-        return cls.configuration_manager.get_value(
-            MySQLConfParser.SERVER_CONF_SECTION).get('datadir')
+    def get_data_dir(self):
+        return self.configuration_manager.get_value(
+            'datadir', section=MySQLConfParser.SERVER_CONF_SECTION)
 
-    @classmethod
-    def set_data_dir(cls, value):
-        cls.configuration_manager.apply_system_override(
+    def set_data_dir(self, value):
+        self.configuration_manager.apply_system_override(
             {MySQLConfParser.SERVER_CONF_SECTION: {'datadir': value}})
 
     def _create_admin_user(self, client, password):
@@ -503,21 +526,21 @@ class BaseMySqlApp(service.BaseDbApp):
 
         engine = sqlalchemy.create_engine(
             CONNECTION_STR_FORMAT % ('root', root_pass), echo=True)
-        with mysql_util.SqlClient(engine, use_flush=False) as client:
+        with mysql_util.SqlClient(engine) as client:
             self._create_admin_user(client, admin_password)
 
         engine = sqlalchemy.create_engine(
             CONNECTION_STR_FORMAT % (ADMIN_USER_NAME,
                                      urllib.parse.quote(admin_password)),
             echo=True)
-        with mysql_util.SqlClient(engine) as client:
+        with mysql_util.SqlClient(engine, use_flush=True) as client:
             self._remove_anonymous_user(client)
 
         self.save_password(ADMIN_USER_NAME, admin_password)
         LOG.info("MySQL secure complete.")
 
     def secure_root(self):
-        with mysql_util.SqlClient(self.get_engine()) as client:
+        with mysql_util.SqlClient(self.get_engine(), use_flush=True) as client:
             self._remove_remote_root_access(client)
 
     def _remove_anonymous_user(self, client):
@@ -567,7 +590,8 @@ class BaseMySqlApp(service.BaseDbApp):
         user = "%s:%s" % (CONF.database_service_uid, CONF.database_service_uid)
 
         # Create folders for mysql on localhost
-        for folder in ['/etc/mysql', '/var/run/mysqld']:
+        for folder in ['/etc/mysql', '/var/run/mysqld',
+                       '/etc/mysql/mysql.conf.d']:
             operating_system.ensure_directory(
                 folder, user=CONF.database_service_uid,
                 group=CONF.database_service_uid, force=True,
@@ -582,13 +606,26 @@ class BaseMySqlApp(service.BaseDbApp):
         if extra_volumes:
             volumes.update(extra_volumes)
 
+        # Expose ports
+        ports = {}
+        tcp_ports = cfg.get_configuration_property('tcp_ports')
+        for port_range in tcp_ports:
+            for port in port_range:
+                ports[f'{port}/tcp'] = port
+
+        if CONF.network_isolation and \
+                os.path.exists(constants.ETH1_CONFIG_PATH):
+            network_mode = constants.DOCKER_HOST_NIC_MODE
+        else:
+            network_mode = constants.DOCKER_BRIDGE_MODE
+
         try:
-            LOG.info("Starting docker container, image: %s", image)
             docker_util.start_container(
                 self.docker_client,
                 image,
                 volumes=volumes,
-                network_mode="host",
+                network_mode=network_mode,
+                ports=ports,
                 user=user,
                 environment={
                     "MYSQL_ROOT_PASSWORD": root_pass,
@@ -630,16 +667,12 @@ class BaseMySqlApp(service.BaseDbApp):
                 LOG.exception("Could not delete logfile.")
                 raise
 
-    def reset_configuration(self, configuration):
-        LOG.info("Resetting configuration.")
-        self.configuration_manager.save_configuration(configuration)
-        self.wipe_ib_logfiles()
-
     def restart(self):
         LOG.info("Restarting mysql")
 
         # Ensure folders permission for database.
-        for folder in ['/etc/mysql', '/var/run/mysqld']:
+        for folder in ['/etc/mysql', '/var/run/mysqld',
+                       '/etc/mysql/mysql.conf.d']:
             operating_system.ensure_directory(
                 folder, user=CONF.database_service_uid,
                 group=CONF.database_service_uid, force=True,
@@ -730,7 +763,7 @@ class BaseMySqlApp(service.BaseDbApp):
         LOG.info("Granting replication slave privilege for %s",
                  replication_user['name'])
 
-        with mysql_util.SqlClient(self.get_engine()) as client:
+        with mysql_util.SqlClient(self.get_engine(), use_flush=True) as client:
             g = sql_query.Grant(permissions=['REPLICATION SLAVE'],
                                 user=replication_user['name'],
                                 clear=replication_user['password'])
@@ -819,6 +852,7 @@ class BaseMySqlApp(service.BaseDbApp):
 
 
 class BaseMySqlRootAccess(object):
+
     def __init__(self, mysql_app):
         self.mysql_app = mysql_app
 
@@ -835,7 +869,8 @@ class BaseMySqlRootAccess(object):
            reset the root password.
         """
         user = models.MySQLUser.root(password=root_password)
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             try:
                 cu = sql_query.CreateUser(user.name, host=user.host)
                 t = text(str(cu))
@@ -844,7 +879,9 @@ class BaseMySqlRootAccess(object):
                 # Ignore, user is already created, just reset the password
                 # TODO(rnirmal): More fine grained error checking later on
                 LOG.debug(err)
-        with mysql_util.SqlClient(self.mysql_app.get_engine()) as client:
+
+        with mysql_util.SqlClient(
+                self.mysql_app.get_engine(), use_flush=True) as client:
             uu = sql_query.SetPassword(
                 user.name, host=user.host, new_password=user.password,
                 ds=CONF.datastore_manager, ds_version=CONF.datastore_version
