@@ -12,20 +12,22 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 from collections import OrderedDict
+import os
 
 from oslo_log import log as logging
 import psycopg2
 
 from trove.common import cfg
+from trove.common import constants
+from trove.common.db.postgresql import models
 from trove.common import exception
 from trove.common import stream_codecs
 from trove.common import utils
-from trove.common.db.postgresql import models
 from trove.guestagent.common import configuration
 from trove.guestagent.common import guestagent_utils
 from trove.guestagent.common import operating_system
-from trove.guestagent.datastore import service
 from trove.guestagent.datastore.postgres import query
+from trove.guestagent.datastore import service
 from trove.guestagent.utils import docker as docker_util
 from trove.instance import service_status
 
@@ -74,18 +76,26 @@ class PgSqlAppStatus(service.BaseDbStatus):
 
 
 class PgSqlApp(service.BaseDbApp):
-    configuration_manager = configuration.ConfigurationManager(
-        CONFIG_FILE,
-        CONF.database_service_uid,
-        CONF.database_service_uid,
-        stream_codecs.KeyValueCodec(
-            value_quoting=True,
-            bool_case=stream_codecs.KeyValueCodec.BOOL_LOWER,
-            big_ints=True),
-        requires_root=True,
-        override_strategy=configuration.ImportOverrideStrategy(
-            CNF_INCLUDE_DIR, CNF_EXT)
-    )
+    _configuration_manager = None
+
+    @property
+    def configuration_manager(self):
+        if self._configuration_manager:
+            return self._configuration_manager
+
+        self._configuration_manager = configuration.ConfigurationManager(
+            CONFIG_FILE,
+            CONF.database_service_uid,
+            CONF.database_service_uid,
+            stream_codecs.KeyValueCodec(
+                value_quoting=True,
+                bool_case=stream_codecs.KeyValueCodec.BOOL_LOWER,
+                big_ints=True),
+            requires_root=True,
+            override_strategy=configuration.ImportOverrideStrategy(
+                CNF_INCLUDE_DIR, CNF_EXT)
+        )
+        return self._configuration_manager
 
     def __init__(self, status, docker_client):
         super(PgSqlApp, self).__init__(status, docker_client)
@@ -96,13 +106,11 @@ class PgSqlApp(service.BaseDbApp):
         self.datadir = f"{mount_point}/data/pgdata"
         self.adm = PgSqlAdmin(SUPER_USER_NAME)
 
-    @classmethod
-    def get_data_dir(cls):
-        return cls.configuration_manager.get_value('data_directory')
+    def get_data_dir(self):
+        return self.configuration_manager.get_value('data_directory')
 
-    @classmethod
-    def set_data_dir(cls, value):
-        cls.configuration_manager.apply_system_override(
+    def set_data_dir(self, value):
+        self.configuration_manager.apply_system_override(
             {'data_directory': value})
 
     def reload(self):
@@ -147,9 +155,6 @@ class PgSqlApp(service.BaseDbApp):
         if overrides:
             self.configuration_manager.apply_user_override(overrides)
 
-    def reset_configuration(self, configuration):
-        self.configuration_manager.save_configuration(configuration)
-
     def apply_overrides(self, overrides):
         """Reload config."""
         cmd = "pg_ctl reload"
@@ -190,13 +195,26 @@ class PgSqlApp(service.BaseDbApp):
         if extra_volumes:
             volumes.update(extra_volumes)
 
+        # Expose ports
+        ports = {}
+        tcp_ports = cfg.get_configuration_property('tcp_ports')
+        for port_range in tcp_ports:
+            for port in port_range:
+                ports[f'{port}/tcp'] = port
+
+        if CONF.network_isolation and \
+                os.path.exists(constants.ETH1_CONFIG_PATH):
+            network_mode = constants.DOCKER_HOST_NIC_MODE
+        else:
+            network_mode = constants.DOCKER_BRIDGE_MODE
+
         try:
-            LOG.info("Starting docker container, image: %s", image)
             docker_util.start_container(
                 self.docker_client,
                 image,
                 volumes=volumes,
-                network_mode="host",
+                network_mode=network_mode,
+                ports=ports,
                 user=user,
                 environment={
                     "POSTGRES_PASSWORD": postgres_pass,
@@ -267,6 +285,9 @@ class PgSqlApp(service.BaseDbApp):
             f'--restore-checksum={backup_info["checksum"]} '
             f'--pg-wal-archive-dir {WAL_ARCHIVE_DIR}'
         )
+        if CONF.backup_aes_cbc_key:
+            command = (f"{command} "
+                       f"--backup-encryption-key={CONF.backup_aes_cbc_key}")
 
         LOG.debug('Stop the database and clean up the data before restore '
                   'from %s', backup_id)
@@ -724,7 +745,17 @@ class PgSqlAdmin(object):
 
 
 class PostgresConnection(object):
-    def __init__(self, user, password=None, host='localhost', port=5432):
+    def __init__(self, user, password=None, host='/var/run/postgresql',
+                 port=5432):
+        """Utility class to communicate with PostgreSQL.
+
+        Connect with socket rather than IP or localhost address to avoid
+        manipulation of pg_hba.conf when the database is running inside
+        container with bridge network.
+
+        This class is consistent with PostgresConnection in
+        backup/utils/postgresql.py
+        """
         self.user = user
         self.password = password
         self.host = host
@@ -747,12 +778,15 @@ class PostgresConnection(object):
     def _execute_stmt(self, statement, identifiers, data_values, fetch,
                       autocommit=False):
         cmd = self._bind(statement, identifiers)
-        with psycopg2.connect(self.connect_str) as connection:
-            connection.autocommit = autocommit
+        connection = psycopg2.connect(self.connect_str)
+        connection.autocommit = autocommit
+        try:
             with connection.cursor() as cursor:
                 cursor.execute(cmd, data_values)
                 if fetch:
                     return cursor.fetchall()
+        finally:
+            connection.close()
 
     def _bind(self, statement, identifiers):
         if identifiers:
