@@ -35,18 +35,18 @@ from trove.common import cfg
 from trove.common import clients
 from trove.common import crypto_utils as cu
 from trove.common import exception
+from trove.common.i18n import _
 from trove.common import neutron
 from trove.common import notification
 from trove.common import server_group as srv_grp
 from trove.common import template
 from trove.common import timeutils
-from trove.common import utils
-from trove.common.i18n import _
 from trove.common.trove_remote import create_trove_client
+from trove.common import utils
 from trove.configuration.models import Configuration
 from trove.datastore import models as datastore_models
-from trove.datastore.models import DBDatastoreVersionMetadata
 from trove.datastore.models import DatastoreVersionMetadata as dvm
+from trove.datastore.models import DBDatastoreVersionMetadata
 from trove.db import get_db_api
 from trove.db import models as dbmodels
 from trove.extensions.security_group.models import SecurityGroup
@@ -141,7 +141,7 @@ def load_simple_instance_server_status(context, db_info):
 
 def load_simple_instance_addresses(context, db_info):
     """Get addresses of the instance from Neutron."""
-    if 'BUILDING' == db_info.task_status.action:
+    if 'BUILDING' == db_info.task_status.action and not db_info.cluster_id:
         db_info.addresses = []
         return
 
@@ -262,18 +262,17 @@ class SimpleInstance(object):
 
     def get_visible_ip_addresses(self):
         """Returns IPs that will be visible to the user."""
-        if self.addresses is None:
+        if not self.addresses:
             return None
 
         IPs = []
-
-        for addr_info in self.addresses:
+        for address in self.addresses:
             if CONF.ip_regex and CONF.black_list_regex:
-                if not ip_visible(addr_info['address'], CONF.ip_regex,
+                if not ip_visible(address['address'], CONF.ip_regex,
                                   CONF.black_list_regex):
                     continue
 
-            IPs.append(addr_info)
+            IPs.append(address)
 
         return IPs
 
@@ -968,25 +967,35 @@ class BaseInstance(SimpleInstance):
         return self._server_group
 
     def prepare_cloud_config(self, files):
-        userdata = (
-            "#cloud-config\n"
-            "write_files:\n"
-        )
+        # This method returns None if the files argument is None
+        userdata = None
 
-        for filename, content in files.items():
-            ud = encodeutils.safe_encode(content)
-            body_userdata = (
-                "- encoding: b64\n"
-                "  owner: trove:trove\n"
-                "  path: %s\n"
-                "  content: %s\n" % (
-                    filename, encodeutils.safe_decode(base64.b64encode(ud)))
+        if files:
+            userdata = (
+                "#cloud-config\n"
+                "write_files:\n"
             )
-            userdata = userdata + body_userdata
 
-        return userdata
+            injected_config_owner = CONF.get('injected_config_owner')
+            injected_config_group = CONF.get('injected_config_group')
+            for filename, content in files.items():
+                ud = encodeutils.safe_encode(content)
+                body_userdata = (
+                    "- encoding: b64\n"
+                    "  owner: %s:%s\n"
+                    "  path: %s\n"
+                    "  content: %s\n" % (
+                        injected_config_owner, injected_config_group, filename,
+                        encodeutils.safe_decode(base64.b64encode(ud)))
+                )
+                userdata = userdata + body_userdata
 
-    def get_injected_files(self, datastore_manager, datastore_version):
+        return userdata if userdata else ""
+
+    def get_injected_files(self,
+                           datastore_manager,
+                           datastore_version,
+                           **kwargs):
         injected_config_location = CONF.get('injected_config_location')
         guest_info = CONF.get('guest_info')
 
@@ -1010,6 +1019,12 @@ class BaseInstance(SimpleInstance):
             )
         }
 
+        # pass through the network_isolation to guest
+        files = {
+            guest_info_file: ("%snetwork_isolation=%s\n" %
+                              (files.get(guest_info_file),
+                               CONF.network.network_isolation))
+        }
         instance_key = get_instance_encryption_key(self.id)
         if instance_key:
             files = {
@@ -1030,6 +1045,31 @@ class BaseInstance(SimpleInstance):
                 f"CONTROLLER={CONF.controller_address}"
             )
 
+        # Since Victoria, guest agent uses docker.
+        # Configure docker's daemon.json if the directives exist in trove.conf
+        docker_daemon_values = {}
+
+        # In case that user enables network_isolation with management/bussiness
+        # network not set
+        if CONF.network.network_isolation and \
+                kwargs.get("disable_bridge", False):
+            docker_daemon_values["bridge"] = "none"
+            docker_daemon_values["ip-forward"] = False
+            docker_daemon_values["iptables"] = False
+        else:
+            # Configure docker_bridge_network_ip in order to change the docker
+            # default range(172.17.0.0/16) of bridge network
+            if CONF.docker_bridge_network_ip:
+                docker_daemon_values["bip"] = CONF.docker_bridge_network_ip
+        if CONF.docker_insecure_registries:
+            docker_daemon_values["insecure-registries"] = \
+                CONF.docker_insecure_registries
+
+        if docker_daemon_values:
+            files['/etc/docker/daemon.json'] = (
+                json.dumps(docker_daemon_values)
+            )
+
         return files
 
     def reset_status(self):
