@@ -24,6 +24,7 @@ import trove.common.apischema as apischema
 from trove.common import cfg
 from trove.common import clients
 from trove.common import exception
+from trove.common import glance as common_glance
 from trove.common.i18n import _
 from trove.common import neutron
 from trove.common import notification
@@ -310,8 +311,8 @@ class InstanceController(wsgi.Controller):
 
         nic['network_id'] = network_id
         nic.pop('net-id', None)
-
-        self._check_network_overlap(context, network_id, subnet_id)
+        if not CONF.network.network_isolation:
+            self._check_network_overlap(context, network_id, subnet_id)
 
     def _check_network_overlap(self, context, user_network=None,
                                user_subnet=None):
@@ -414,7 +415,13 @@ class InstanceController(wsgi.Controller):
             datastore, datastore_version = ds_models.get_datastore_version(
                 **datastore_args)
 
-        image_id = datastore_version.image_id
+        # If only image_tags is configured in the datastore version, get
+        # the image ID using the tags.
+        glance_client = clients.create_glance_client(context)
+        image_id = common_glance.get_image_id(
+            glance_client, datastore_version.image_id,
+            datastore_version.image_tags)
+        LOG.info(f'Using image {image_id} for creating instance')
 
         databases = populate_validated_databases(
             body['instance'].get('databases', []))
@@ -424,7 +431,7 @@ class InstanceController(wsgi.Controller):
             users = populate_users(body['instance'].get('users', []),
                                    database_names)
         except ValueError as ve:
-            raise exception.BadRequest(message=ve)
+            raise exception.BadRequest(message=str(ve))
         if slave_of_id and (databases or users):
             raise exception.ReplicaCreateWithUsersDatabasesError()
 
@@ -521,6 +528,12 @@ class InstanceController(wsgi.Controller):
         elif 'datastore_version' in kwargs:
             datastore_version = ds_models.DatastoreVersion.load(
                 instance.datastore, kwargs['datastore_version'])
+
+            if datastore_version.name == instance.ds_version.name:
+                LOG.warning(f"Same datastore version {datastore_version.name} "
+                            f"for upgrading")
+                return
+
             context.notification = (
                 notification.DBaaSInstanceUpgrade(context, request=req))
             with StartNotification(context, instance_id=instance.id,
@@ -545,7 +558,7 @@ class InstanceController(wsgi.Controller):
 
         name = body['instance'].get('name')
         if ((name and len(body['instance'].keys()) > 2) or
-            (not name and len(body['instance'].keys()) >= 2)):
+                (not name and len(body['instance'].keys()) >= 2)):
             raise exception.BadRequest("Only one attribute (except 'name') is "
                                        "allowed to update.")
 
@@ -568,6 +581,9 @@ class InstanceController(wsgi.Controller):
         if 'access' in body['instance']:
             args['access'] = body['instance']['access']
 
+        if 'datastore_version' in body['instance']:
+            args['datastore_version'] = body['instance']['datastore_version']
+
         self._modify_instance(context, req, instance, **args)
         return wsgi.Result(None, 202)
 
@@ -576,7 +592,7 @@ class InstanceController(wsgi.Controller):
 
         Deprecated. Use update method instead.
         """
-        self.update(req, id, body, tenant_id)
+        return self.update(req, id, body, tenant_id)
 
     def configuration(self, req, tenant_id, id):
         """
