@@ -13,6 +13,7 @@
 #    under the License.
 
 import copy
+import json
 import time
 import traceback
 
@@ -21,24 +22,20 @@ from eventlet.timeout import Timeout
 from oslo_log import log as logging
 from swiftclient.client import ClientException
 
-from trove import rpc
 from trove.backup import models as bkup_models
 from trove.backup.models import Backup
 from trove.backup.models import DBBackup
 from trove.backup.state import BackupState
-from trove.cluster import tasks
 from trove.cluster.models import Cluster
 from trove.cluster.models import DBCluster
+from trove.cluster import tasks
 from trove.common import cfg
 from trove.common import clients
-from trove.common import exception
-from trove.common import neutron
-from trove.common import template
-from trove.common import timeutils
-from trove.common import utils
 from trove.common.clients import create_cinder_client
 from trove.common.clients import create_dns_client
 from trove.common.clients import create_guest_client
+from trove.common import constants
+from trove.common import exception
 from trove.common.exception import BackupCreationError
 from trove.common.exception import GuestError
 from trove.common.exception import GuestTimeout
@@ -47,6 +44,7 @@ from trove.common.exception import PollTimeOut
 from trove.common.exception import TroveError
 from trove.common.exception import VolumeCreationFailure
 from trove.common.i18n import _
+from trove.common import neutron
 from trove.common.notification import DBaaSInstanceRestart
 from trove.common.notification import DBaaSInstanceUpgrade
 from trove.common.notification import EndNotification
@@ -54,20 +52,24 @@ from trove.common.notification import StartNotification
 from trove.common.notification import TroveInstanceCreate
 from trove.common.notification import TroveInstanceModifyFlavor
 from trove.common.strategies.cluster import strategy
+from trove.common import template
+from trove.common import timeutils
+from trove.common import utils
 from trove.common.utils import try_recover
 from trove.configuration import models as config_models
 from trove.extensions.mysql import models as mysql_models
 from trove.instance import models as inst_models
-from trove.instance import service_status as srvstatus
 from trove.instance.models import DBInstance
 from trove.instance.models import FreshInstance
 from trove.instance.models import Instance
 from trove.instance.models import InstanceServiceStatus
 from trove.instance.models import InstanceStatus
+from trove.instance import service_status as srvstatus
 from trove.instance.tasks import InstanceTasks
 from trove.module import models as module_models
 from trove.module import views as module_views
 from trove.quota.quota import run_with_quotas
+from trove import rpc
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -116,7 +118,7 @@ class NotifyMixin(object):
             'state_description': self.status,
             'state': self.status,
             'tenant_id': self.tenant_id,
-            'user_id': self.context.user,
+            'user_id': self.context.user_id,
         }
 
         if CONF.get(self.datastore_version.manager).volume_support:
@@ -557,6 +559,26 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         )
         return networks
 
+    def _get_user_nic_info(self, port_id):
+        nic_info = dict()
+        port = self.neutron_client.show_port(port_id)
+        fixed_ips = port['port']["fixed_ips"]
+        nic_info["mac_address"] = port['port']["mac_address"]
+        for fixed_ip in fixed_ips:
+            subnet = self.neutron_client.show_subnet(
+                fixed_ip["subnet_id"])['subnet']
+            if subnet.get("ip_version") == 4:
+                nic_info["ipv4_address"] = fixed_ip.get("ip_address")
+                nic_info["ipv4_cidr"] = subnet.get("cidr")
+                nic_info["ipv4_gateway"] = subnet.get("gateway_ip")
+                nic_info["ipv4_host_routes"] = subnet.get("host_routes")
+            elif subnet.get("ip_version") == 6:
+                nic_info["ipv6_address"] = fixed_ip.get("ip_address")
+                nic_info["ipv6_cidr"] = subnet.get("cidr")
+                nic_info["ipv6_gateway"] = subnet.get("gateway_ip")
+                nic_info["ipv6_host_routes"] = subnet.get("host_routes")
+        return nic_info
+
     def create_instance(self, flavor, image_id, databases, users,
                         datastore_manager, packages, volume_size,
                         backup_id, availability_zone, root_password, nics,
@@ -573,11 +595,21 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             "Creating instance %s, nics: %s, access: %s",
             self.id, nics, access
         )
-
         networks = self._prepare_networks_for_instance(
             datastore_manager, nics, access=access
         )
-        files = self.get_injected_files(datastore_manager, ds_version)
+
+        if CONF.network.network_isolation and len(nics) > 1:
+            # the user defined port is always the first one.
+            nic_info = self._get_user_nic_info(networks[0]["port-id"])
+            LOG.debug("Generate the eth1_config.json file: %s", nic_info)
+            files = self.get_injected_files(datastore_manager,
+                                            ds_version,
+                                            disable_bridge=True)
+            files[constants.ETH1_CONFIG_PATH] = json.dumps(nic_info)
+        else:
+            files = self.get_injected_files(datastore_manager, ds_version)
+
         cinder_volume_type = volume_type or CONF.cinder_volume_type
         volume_info = self._create_server_volume(
             flavor['id'], image_id,
@@ -980,7 +1012,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                        nics, files={}, scheduler_hints=None):
         userdata = self.prepare_userdata(datastore_manager)
         metadata = {'trove_project_id': self.tenant_id,
-                    'trove_user_id': self.context.user,
+                    'trove_user_id': self.context.user_id,
                     'trove_instance_id': self.id}
         bdmap_v2 = block_device_mapping_v2
         config_drive = CONF.use_nova_server_config_drive
@@ -988,7 +1020,7 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
 
         # Use config_drive instead by userdata
         # We will inject guest config by cloud-config
-        if not config_drive:
+        if files:
             if not userdata:
                 userdata = self.prepare_cloud_config(files)
             else:
