@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from novaclient.exceptions import BadRequest
 from novaclient.v2.servers import Server
 from oslo_messaging._drivers.common import RPCException
@@ -22,13 +23,13 @@ from testtools import TestCase
 
 from trove.common.exception import PollTimeOut
 from trove.common.exception import TroveError
-from trove.common import instance as rd_instance
 from trove.common import template
 from trove.common import utils
 from trove.datastore.models import DatastoreVersion
 from trove.guestagent import api as guest
 from trove.instance.models import DBInstance
 from trove.instance.models import InstanceServiceStatus
+from trove.instance import service_status as srvstatus
 from trove.instance.tasks import InstanceTasks
 from trove.taskmanager import models
 from trove.tests.fakes import nova
@@ -62,7 +63,7 @@ class ResizeTestBase(TestCase):
             self.server,
             datastore_status=InstanceServiceStatus.create(
                 instance_id=self.db_info.id,
-                status=rd_instance.ServiceStatuses.RUNNING))
+                status=srvstatus.ServiceStatuses.RUNNING))
         self.instance.server.flavor = {'id': OLD_FLAVOR_ID}
         self.guest = mock.MagicMock(spec=guest.API)
         self.instance._guest = self.guest
@@ -113,28 +114,29 @@ class ResizeTests(ResizeTestBase):
         datastore.manager = 'mysql'
         config = template.SingleInstanceConfigTemplate(
             datastore, NEW_FLAVOR.__dict__, self.instance.id)
-        self.instance.guest.start_db_with_conf_changes(config.render())
+        self.instance.guest.start_db_with_conf_changes(config.render(),
+                                                       datastore.name)
 
     def test_guest_wont_stop_mysql(self):
         self.guest.stop_db.side_effect = RPCException("Could not stop MySQL!")
         self.assertRaises(RPCException, self.action.execute)
-        self.guest.stop_db.assert_called_once_with(do_not_start_on_reboot=True)
+        self.assertEqual(1, self.guest.stop_db.call_count)
         self.instance.update_db.assert_called_once_with(
             task_status=InstanceTasks.NONE)
 
     def test_nova_wont_resize(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
         self.server.resize.side_effect = BadRequest(400)
         self.server.status = "ACTIVE"
         self.assertRaises(BadRequest, self.action.execute)
-        self.guest.stop_db.assert_called_once_with(do_not_start_on_reboot=True)
+        self.assertEqual(1, self.guest.stop_db.call_count)
         self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
         self.guest.restart.assert_called_once()
         self.instance.update_db.assert_called_once_with(
             task_status=InstanceTasks.NONE)
 
     def test_nova_resize_timeout(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
         self.server.status = "ACTIVE"
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
@@ -143,14 +145,13 @@ class ResizeTests(ResizeTestBase):
             expected_calls = [
                 mock.call(mock.ANY, sleep_time=2, time_out=120)] * 2
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
             self.instance.update_db.assert_called_once_with(
                 task_status=InstanceTasks.NONE)
 
     def test_nova_doesnt_change_flavor(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
             self.poll_until_side_effects.extend([
@@ -167,8 +168,7 @@ class ResizeTests(ResizeTestBase):
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
             # Make sure self.poll_until_side_effects is empty
             self.assertFalse(self.poll_until_side_effects)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
             self.instance.guest.reset_configuration.assert_called_once_with(
                 mock.ANY)
@@ -178,7 +178,7 @@ class ResizeTests(ResizeTestBase):
                 task_status=InstanceTasks.NONE)
 
     def test_nova_resize_fails(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
             self.poll_until_side_effects.extend([
@@ -195,14 +195,13 @@ class ResizeTests(ResizeTestBase):
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
             # Make sure self.poll_until_side_effects is empty
             self.assertFalse(self.poll_until_side_effects)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
             self.instance.update_db.assert_called_once_with(
                 task_status=InstanceTasks.NONE)
 
     def test_nova_resizes_in_weird_state(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
             self.poll_until_side_effects.extend([
@@ -219,15 +218,14 @@ class ResizeTests(ResizeTestBase):
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
             # Make sure self.poll_until_side_effects is empty
             self.assertFalse(self.poll_until_side_effects)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
             self.guest.restart.assert_called_once()
             self.instance.update_db.assert_called_once_with(
                 task_status=InstanceTasks.NONE)
 
     def test_guest_is_not_okay(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
             self.poll_until_side_effects.extend([
@@ -240,7 +238,7 @@ class ResizeTests(ResizeTestBase):
 
             self.instance.set_datastore_status_to_paused.side_effect = (
                 lambda: self._datastore_changes_to(
-                    rd_instance.ServiceStatuses.PAUSED))
+                    srvstatus.ServiceStatuses.PAUSED))
 
             self.assertRaises(PollTimeOut, self.action.execute)
 
@@ -249,8 +247,7 @@ class ResizeTests(ResizeTestBase):
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
             # Make sure self.poll_until_side_effects is empty
             self.assertFalse(self.poll_until_side_effects)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
             self.instance.set_datastore_status_to_paused.assert_called_once()
             self.instance.guest.reset_configuration.assert_called_once_with(
@@ -261,7 +258,7 @@ class ResizeTests(ResizeTestBase):
                 task_status=InstanceTasks.NONE)
 
     def test_mysql_is_not_okay(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
             self.poll_until_side_effects.extend([
@@ -273,7 +270,7 @@ class ResizeTests(ResizeTestBase):
 
             self.instance.set_datastore_status_to_paused.side_effect = (
                 lambda: self._datastore_changes_to(
-                    rd_instance.ServiceStatuses.SHUTDOWN))
+                    srvstatus.ServiceStatuses.SHUTDOWN))
 
             self._start_mysql()
             self.assertRaises(PollTimeOut, self.action.execute)
@@ -283,8 +280,7 @@ class ResizeTests(ResizeTestBase):
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
             # Make sure self.poll_until_side_effects is empty
             self.assertFalse(self.poll_until_side_effects)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
             self.instance.set_datastore_status_to_paused.assert_called_once()
             self.instance.guest.reset_configuration.assert_called_once_with(
@@ -295,7 +291,7 @@ class ResizeTests(ResizeTestBase):
                 task_status=InstanceTasks.NONE)
 
     def test_confirm_resize_fails(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
             self.poll_until_side_effects.extend([
@@ -308,7 +304,7 @@ class ResizeTests(ResizeTestBase):
 
             self.instance.set_datastore_status_to_paused.side_effect = (
                 lambda: self._datastore_changes_to(
-                    rd_instance.ServiceStatuses.RUNNING))
+                    srvstatus.ServiceStatuses.RUNNING))
             self.server.confirm_resize.side_effect = BadRequest(400)
 
             self._start_mysql()
@@ -319,8 +315,7 @@ class ResizeTests(ResizeTestBase):
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
             # Make sure self.poll_until_side_effects is empty
             self.assertFalse(self.poll_until_side_effects)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
             self.instance.set_datastore_status_to_paused.assert_called_once()
             self.instance.server.confirm_resize.assert_called_once()
@@ -328,7 +323,7 @@ class ResizeTests(ResizeTestBase):
                 task_status=InstanceTasks.NONE)
 
     def test_revert_nova_fails(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
             self.poll_until_side_effects.extend([
@@ -341,7 +336,7 @@ class ResizeTests(ResizeTestBase):
 
             self.instance.set_datastore_status_to_paused.side_effect = (
                 lambda: self._datastore_changes_to(
-                    rd_instance.ServiceStatuses.PAUSED))
+                    srvstatus.ServiceStatuses.PAUSED))
 
             self.assertRaises(PollTimeOut, self.action.execute)
 
@@ -350,8 +345,7 @@ class ResizeTests(ResizeTestBase):
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
             # Make sure self.poll_until_side_effects is empty
             self.assertFalse(self.poll_until_side_effects)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.resize.assert_called_once_with(NEW_FLAVOR_ID)
             self.instance.set_datastore_status_to_paused.assert_called_once()
             self.instance.guest.reset_configuration.assert_called_once_with(
@@ -370,7 +364,7 @@ class MigrateTests(ResizeTestBase):
         self.action = models.MigrateAction(self.instance)
 
     def test_successful_migrate(self):
-        self._datastore_changes_to(rd_instance.ServiceStatuses.SHUTDOWN)
+        self._datastore_changes_to(srvstatus.ServiceStatuses.SHUTDOWN)
 
         with mock.patch.object(utils, 'poll_until') as mock_poll_until:
             self.poll_until_side_effects.extend([
@@ -382,7 +376,7 @@ class MigrateTests(ResizeTestBase):
 
             self.instance.set_datastore_status_to_paused.side_effect = (
                 lambda: self._datastore_changes_to(
-                    rd_instance.ServiceStatuses.RUNNING))
+                    srvstatus.ServiceStatuses.RUNNING))
 
             self.action.execute()
 
@@ -391,8 +385,7 @@ class MigrateTests(ResizeTestBase):
             self.assertEqual(expected_calls, mock_poll_until.call_args_list)
             # Make sure self.poll_until_side_effects is empty
             self.assertFalse(self.poll_until_side_effects)
-            self.guest.stop_db.assert_called_once_with(
-                do_not_start_on_reboot=True)
+            self.assertEqual(1, self.guest.stop_db.call_count)
             self.server.migrate.assert_called_once_with(force_host=None)
             self.instance.set_datastore_status_to_paused.assert_called_once()
             self.instance.server.confirm_resize.assert_called_once()
