@@ -16,6 +16,7 @@ import datetime
 from unittest.mock import DEFAULT
 from unittest.mock import MagicMock
 from unittest.mock import patch
+
 from swiftclient.client import ClientException
 
 from trove.backup import models
@@ -33,7 +34,7 @@ from trove.tests.unittests.util import util
 
 def _prep_conf(current_time):
     current_time = str(current_time)
-    _context = context.TroveContext(tenant='TENANT-' + current_time)
+    _context = context.TroveContext(project_id='TENANT-' + current_time)
     instance_id = 'INSTANCE-' + current_time
     return _context, instance_id
 
