@@ -11,9 +11,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+import uuid
+
 from unittest.mock import Mock
 from unittest.mock import patch
-import uuid
 
 from trove.backup import models as backup_models
 from trove.common import cfg
@@ -50,11 +51,17 @@ class SimpleInstanceTest(trove_testtools.TestCase):
                 ServiceStatuses.BUILDING), ds_version=Mock(), ds=Mock(),
             locality='affinity')
         self.instance.context = self.context
-        db_info.addresses = [
-            {'type': 'private', 'address': '123.123.123.123'},
-            {'type': 'private', 'address': '10.123.123.123'},
-            {'type': 'public', 'address': '15.123.123.123'},
-        ]
+        db_info.addresses = [{
+            'type': 'private',
+            'address': '123.123.123.123',
+            'network': 'net-id-private'}, {
+            'type': 'private',
+            'address': '10.123.123.123',
+            'network': 'net-id-private'}, {
+            'type': 'public',
+            'address': '15.123.123.123',
+            'network': 'net-id-public'}]
+
         self.orig_ip_regex = CONF.ip_regex
         self.orig_black_list_regex = CONF.black_list_regex
 
@@ -76,16 +83,14 @@ class SimpleInstanceTest(trove_testtools.TestCase):
         CONF.ip_regex = '^(15.|123.)'
         CONF.black_list_regex = '^10.123.123.*'
         ip = self.instance.get_visible_ip_addresses()
-        ip = [addr['address'] for addr in ip]
         self.assertEqual(2, len(ip))
-        self.assertIn('123.123.123.123', ip)
-        self.assertIn('15.123.123.123', ip)
+        self.assertIn('123.123.123.123', ip[0].get('address'))
+        self.assertIn('15.123.123.123', ip[1].get('address'))
 
     def test_filter_ips_black_list(self):
         CONF.ip_regex = '.*'
         CONF.black_list_regex = '^10.123.123.*'
         ip = self.instance.get_visible_ip_addresses()
-        ip = [addr['address'] for addr in ip]
         self.assertEqual(2, len(ip))
         self.assertNotIn('10.123.123.123', ip)
 
